@@ -2,7 +2,7 @@
 :author: two-it2022
 '''
 
-from .color import ( colour, colorprint, colors )
+from .colour import ( colour, colourprint, colours )
 from .table import ( Table )
 from .asynchat import ( Server, Client, HOST_IP )
 
